==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24FocusHandler.h <==
// public class javax.swing.plaf.basic.BasicTabbedPaneUI$FocusHandler

// class file dependencies
// @dep_class 85d029885a60bde1 java_awt_event_FocusAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b1e1a2b069e7185b javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler

// header file dependencies
// @dep_header java_awt_event_FocusAdapter

#include "java/awt/event/FocusAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_FocusEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$method$_init$492a22a5dd7abeec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$method$focusGained$2b0b3146a729e224(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$method$focusLost$b4af7a719a65818b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$method_info$focusGained$2b0b3146a729e224;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$method_info$focusLost$b4af7a719a65818b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vmethods {
	void	(*focusGained$2b0b3146a729e224)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);
	void	(*focusLost$b4af7a719a65818b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_FocusAdapter$vmethods	java_awt_event_FocusAdapter;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler;
    _jc_java_awt_event_FocusAdapter$sub_refs	java_awt_event_FocusAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_FocusAdapter$sub_nonrefs	java_awt_event_FocusAdapter;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24FocusHandler.h <==
// public class javax.swing.plaf.basic.BasicTabbedPaneUI$FocusHandler

// class file dependencies
// @dep_class 85d029885a60bde1 java_awt_event_FocusAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b1e1a2b069e7185b javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler

// header file dependencies
// @dep_header java_awt_event_FocusAdapter

#include "java/awt/event/FocusAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_FocusEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$method$_init$492a22a5dd7abeec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$method$focusGained$2b0b3146a729e224(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$method$focusLost$b4af7a719a65818b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$method_info$focusGained$2b0b3146a729e224;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$method_info$focusLost$b4af7a719a65818b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vmethods {
	void	(*focusGained$2b0b3146a729e224)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
	void	(*focusLost$b4af7a719a65818b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_FocusAdapter$vmethods	java_awt_event_FocusAdapter;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler;
    _jc_java_awt_event_FocusAdapter$sub_refs	java_awt_event_FocusAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_FocusAdapter$sub_nonrefs	java_awt_event_FocusAdapter;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24FocusHandler_H_ */
